Type Definition iroh_rpc_client::ChannelTypes
source · pub type ChannelTypes = CombinedChannelTypes<Http2ChannelTypes, MemChannelTypes>;Expand description
The types of channels used by the client and server.
pub type ChannelTypes = CombinedChannelTypes<Http2ChannelTypes, MemChannelTypes>;The types of channels used by the client and server.